<?php

/**
 * Theme Settings Panel.
 *
 * @package Blogging Icon
 */

$default = blogging_icon_get_default_theme_options();

/*slider and its property section*/
require get_template_directory().'/inc/customizer/slider.php';

// Load the radio image control class.
    require_once( trailingslashit( get_template_directory() ) . 'inc/control-radio-image.php' );

    // Register the radio image control class as a JS control type.
    $wp_customize->register_control_type( 'Blogging_Icon_Customize_Control_Radio_Image' );

// Add Theme Settings Panel.
$wp_customize->add_panel('theme_option_panel',
	array(
		'title'      => esc_html__('Theme Settings', 'blogging-icon'),
		'priority'   => 100,
		'capability' => 'edit_theme_options',
	)
);
$wp_customize->add_panel('theme_main_panel',
	array(
		'title'      => esc_html__('Main Settings', 'blogging-icon'),
		'priority'   => 99,
		'capability' => 'edit_theme_options',
	)
);

/*layout management section start */
$wp_customize->add_section('theme_option_section_settings',
	array(
		'title'      => esc_html__('Layout Management', 'blogging-icon'),
		'priority'   => 100,
		'capability' => 'edit_theme_options',
		'panel'      => 'theme_main_panel',
	)
);

/*Home Page Layout*/
$wp_customize->add_setting('enable_overlay_option',
	array(
		'default'           => $default['enable_overlay_option'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'blogging_icon_sanitize_checkbox',
	)
);
$wp_customize->add_control('enable_overlay_option',
	array(
		'label'    => esc_html__('Enable Banner Overlay', 'blogging-icon'),
		'section'  => 'theme_option_section_settings',
		'type'     => 'checkbox',
		'priority' => 150,
	)
);

/*Home Page Layout*/
$wp_customize->add_setting('homepage_layout_option',
	array(
		'default'           => $default['homepage_layout_option'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'blogging_icon_sanitize_select',
	)
);
$wp_customize->add_control('homepage_layout_option',
	array(
		'label'       => esc_html__('Site Layout', 'blogging-icon'),
		'section'     => 'theme_option_section_settings',
		'choices'     => array(
			'full-width' => esc_html__('Full Width', 'blogging-icon'),
			'boxed'      => esc_html__('Boxed', 'blogging-icon'),
		),
		'type'     => 'select',
		'priority' => 160,
	)
);
// Colors
	$wp_customize->add_section( 'blogging_icon_new_section_site_colors' , array(
        'title'      => esc_html__('Site Colors', 'blogging-icon'),
        'description'=> '',
        'priority'   => 95,
        'panel'      => 'theme_main_panel',
    ) );

	$wp_customize->add_setting(
        'blogging_icon_site_color',
        array(
            'default'     => '#434343',
            'sanitize_callback' => 'sanitize_hex_color'
        )
    );
    $wp_customize->add_setting(
        'blogging_icon_header_bg',
        array(
            'default'     => '#fff',
            'sanitize_callback' => 'sanitize_hex_color'
        )
    );
    $wp_customize->add_setting(
        'blogging_icon_topbar_bg',
        array(
            'default'     => '#fafafa',
            'sanitize_callback' => 'sanitize_hex_color'
        )
    );
    $wp_customize->add_setting(
        'blogging_icon_footer_bg',
        array(
            'default'     => '#272727',
            'sanitize_callback' => 'sanitize_hex_color'
        )
    );

    $wp_customize->add_control(
        new WP_Customize_Color_Control(
            $wp_customize,
            'blogging_icon_header_bg',
            array(
                'label'      => esc_html__('Header Background', 'blogging-icon'),
                'section'    => 'blogging_icon_new_section_site_colors',
                'settings'   => 'blogging_icon_header_bg',
                'priority'   => 1
            )
        )
    );
    $wp_customize->add_control(
        new WP_Customize_Color_Control(
            $wp_customize,
            'blogging_icon_topbar_bg',
            array(
                'label'      => esc_html__('Topbar Background', 'blogging-icon'),
                'section'    => 'blogging_icon_new_section_site_colors',
                'settings'   => 'blogging_icon_topbar_bg',
                'priority'   => 3
            )
        )
    );
    $wp_customize->add_control(
        new WP_Customize_Color_Control(
            $wp_customize,
            'blogging_icon_footer_bg',
            array(
                'label'      => esc_html__('Footer Background', 'blogging-icon'),
                'section'    => 'blogging_icon_new_section_site_colors',
                'settings'   => 'blogging_icon_footer_bg',
                'priority'   => 4
            )
        )
    );
    $wp_customize->add_control(
        new WP_Customize_Color_Control(
            $wp_customize,
            'blogging_icon_site_color',
            array(
                'label'      => esc_html__('Site Color', 'blogging-icon'),
                'section'    => 'blogging_icon_new_section_site_colors',
                'settings'   => 'blogging_icon_site_color',
                'priority'   => 2
            )
        )
    );
// Main Options Section
	$wp_customize->add_section(
		'main', 
		array(    
			'title'       => esc_html__('Nav Settings', 'blogging-icon'), 
			'priority' 	  => 6,
			'panel'      => 'theme_main_panel',   
		)
	);

	$wp_customize->add_setting(
		'nav_layout',
		array(
			'default'           => 'center',
			'sanitize_callback' => 'sanitize_key',
		)
	);
	$wp_customize->add_control(
		new Blogging_Icon_Customize_Control_Radio_Image(
			$wp_customize,
			'nav_layout', 
			array(
				'label'    => esc_html__( 'Navigation Layout', 'blogging-icon' ),
				'choices'  => array(
					'center'  => array(
                        'label' => esc_html__( 'Center', 'blogging-icon' ),
                        'url'   => '%s/assets/images/nav_center.png'
                    ),
					'left'   => array(
                        'label' => esc_html__( 'Left', 'blogging-icon' ),
                        'url'   => '%s/assets/images/nav_left.png'
                    ),
			),
			'section'  => 'main',
			'settings'   => 'nav_layout',
			'priority' => 6,
			)
		) 
	);

	// google fonts
    require_once( dirname( __FILE__ ) . '/google-fonts/fonts.php' );


    $wp_customize->add_section( 'blogging_icon_google_fonts', array(
        'title'    => esc_html__( 'Fonts', 'blogging-icon' ),
        'priority' => 50,
        'panel'      => 'theme_main_panel',
    ) );

    $wp_customize->add_setting( 'blogging_icon_google_fonts_heading_font', array(
        'default'           => 'none',
        'type'              => 'theme_mod',
        'capability'        => 'edit_theme_options',
        'transport'         => 'postMessage',
        'sanitize_callback' => 'sanitize_text_field',
    ) );

    $wp_customize->add_control( 'blogging_icon_google_fonts_heading_font', array(
        'label'    => esc_html__( 'Header Font', 'blogging-icon' ),
        'section'  => 'blogging_icon_google_fonts',
        'settings' => 'blogging_icon_google_fonts_heading_font',
        'type'     => 'select',
        'choices'  => $font_choices,
    ) );

    $wp_customize->add_setting( 'blogging_icon_google_fonts_body_font', array(
        'default'           => 'none',
        'type'              => 'theme_mod',
        'capability'        => 'edit_theme_options',
        'transport'         => 'postMessage',
        'sanitize_callback' => 'sanitize_text_field',
    ) );

    $wp_customize->add_control( 'blogging_icon_google_fonts_body_font', array(
        'label'    => esc_html__( 'Body Font', 'blogging-icon' ),
        'section'  => 'blogging_icon_google_fonts',
        'settings' => 'blogging_icon_google_fonts_body_font',
        'type'     => 'select',
        'choices'  => $font_choices,
    ) );
    // end google fonts
/*Global Layout*/
$wp_customize->add_setting('global_layout',
	array(
		'default'           => $default['global_layout'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'blogging_icon_sanitize_select',
	)
);
$wp_customize->add_control('global_layout',
	array(
		'label'          => esc_html__('Global Layout', 'blogging-icon'),
		'section'        => 'theme_option_section_settings',
		'choices'        => array(
			'left-sidebar'  => esc_html__('Primary Sidebar - Content', 'blogging-icon'),
			'right-sidebar' => esc_html__('Content - Primary Sidebar', 'blogging-icon'),
			'no-sidebar'    => esc_html__('No Sidebar', 'blogging-icon'),
		),
		'type'     => 'select',
		'priority' => 170,
	)
);

// Setting - read_more_button_text.
$wp_customize->add_setting('read_more_button_text',
	array(
		'default'           => $default['read_more_button_text'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'sanitize_text_field',
	)
);
$wp_customize->add_control('read_more_button_text',
	array(
		'label'    => esc_html__('Read More Button Text', 'blogging-icon'),
		'section'  => 'theme_option_section_settings',
		'type'     => 'text',
		'priority' => 170,
	)
);

/*content excerpt in global*/
$wp_customize->add_setting('excerpt_length_global',
	array(
		'default'           => $default['excerpt_length_global'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'blogging_icon_sanitize_positive_integer',
	)
);
$wp_customize->add_control('excerpt_length_global',
	array(
		'label'       => esc_html__('Set Global Archive Length', 'blogging-icon'),
		'section'     => 'theme_option_section_settings',
		'type'        => 'number',
		'priority'    => 175,
		'input_attrs' => array('min' => 1, 'max' => 200, 'style' => 'width: 150px;'),

	)
);

/*Archive Layout text*/
$wp_customize->add_setting('archive_layout',
	array(
		'default'           => $default['archive_layout'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'blogging_icon_sanitize_select',
	)
);
$wp_customize->add_control('archive_layout',
	array(
		'label'         => esc_html__('Archive Layout', 'blogging-icon'),
		'section'       => 'theme_option_section_settings',
		'choices'       => array(
			'excerpt-only' => esc_html__('Excerpt Only', 'blogging-icon'),
			'full-post'    => esc_html__('Full Post', 'blogging-icon'),
		),
		'type'     => 'select',
		'priority' => 180,
	)
);

/*Archive Layout image*/
$wp_customize->add_setting('archive_layout_image',
	array(
		'default'           => $default['archive_layout_image'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'blogging_icon_sanitize_select',
	)
);
$wp_customize->add_control('archive_layout_image',
	array(
		'label'     => esc_html__('Archive Image Allocation', 'blogging-icon'),
		'section'   => 'theme_option_section_settings',
		'choices'   => array(
			'full'     => esc_html__('Full', 'blogging-icon'),
			'right'    => esc_html__('Right', 'blogging-icon'),
			'left'     => esc_html__('Left', 'blogging-icon'),
			'no-image' => esc_html__('No image', 'blogging-icon')
		),
		'type'     => 'select',
		'priority' => 185,
	)
);

/*single post Layout image*/
$wp_customize->add_setting('single_post_image_layout',
	array(
		'default'           => $default['single_post_image_layout'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'blogging_icon_sanitize_select',
	)
);
$wp_customize->add_control('single_post_image_layout',
	array(
		'label'     => esc_html__('Single Post/Page Image Allocation', 'blogging-icon'),
		'section'   => 'theme_option_section_settings',
		'choices'   => array(
			'full'     => esc_html__('Full', 'blogging-icon'),
			'right'    => esc_html__('Right', 'blogging-icon'),
			'left'     => esc_html__('Left', 'blogging-icon'),
			'no-image' => esc_html__('No image', 'blogging-icon')
		),
		'type'     => 'select',
		'priority' => 190,
	)
);

// Pagination Section.
$wp_customize->add_section('pagination_section',
	array(
		'title'      => esc_html__('Pagination Options', 'blogging-icon'),
		'priority'   => 110,
		'capability' => 'edit_theme_options',
		'panel'      => 'theme_option_panel',
	)
);

// Setting pagination_type.
$wp_customize->add_setting('pagination_type',
	array(
		'default'           => $default['pagination_type'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'blogging_icon_sanitize_select',
	)
);
$wp_customize->add_control('pagination_type',
	array(
		'label'    => esc_html__('Pagination Type', 'blogging-icon'),
		'section'  => 'pagination_section',
		'type'     => 'select',
		'choices'  => array(
			'default' => esc_html__('Default (Older / Newer Post)', 'blogging-icon'),
			'numeric' => esc_html__('Numeric', 'blogging-icon'),
		),
		'priority' => 100,
	)
);

// Footer Section.
$wp_customize->add_section('footer_section',
	array(
		'title'      => esc_html__('Footer Options', 'blogging-icon'),
		'priority'   => 130,
		'capability' => 'edit_theme_options',
		'panel'      => 'theme_option_panel',
	)
);

// Setting social_content_heading.
$wp_customize->add_setting('number_of_footer_widget',
	array(
		'default'           => $default['number_of_footer_widget'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'blogging_icon_sanitize_select',
	)
);
$wp_customize->add_control('number_of_footer_widget',
	array(
		'label'    => esc_html__('Number Of Footer Widget', 'blogging-icon'),
		'section'  => 'footer_section',
		'type'     => 'select',
		'priority' => 100,
		'choices'  => array(
			0         => esc_html__('Disable footer sidebar area', 'blogging-icon'),
			1         => esc_html__('1', 'blogging-icon'),
			2         => esc_html__('2', 'blogging-icon'),
			3         => esc_html__('3', 'blogging-icon'),
		),
	)
);

// Setting copyright_text.
$wp_customize->add_setting('copyright_text',
	array(
		'default'           => $default['copyright_text'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'sanitize_text_field',
	)
);
$wp_customize->add_control('copyright_text',
	array(
		'label'    => esc_html__('Footer Copyright Text', 'blogging-icon'),
		'section'  => 'footer_section',
		'type'     => 'text',
		'priority' => 120,
	)
);

// Breadcrumb Section.
$wp_customize->add_section('breadcrumb_section',
	array(
		'title'      => esc_html__('Breadcrumb Options', 'blogging-icon'),
		'priority'   => 120,
		'capability' => 'edit_theme_options',
		'panel'      => 'theme_option_panel',
	)
);

// Setting breadcrumb_type.
$wp_customize->add_setting('breadcrumb_type',
	array(
		'default'           => $default['breadcrumb_type'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'blogging_icon_sanitize_select',
	)
);
$wp_customize->add_control('breadcrumb_type',
	array(
		'label'       => esc_html__('Breadcrumb Type', 'blogging-icon'),
		'description' => sprintf(esc_html__('Advanced: Requires %1$sBreadcrumb NavXT%2$s plugin', 'blogging-icon'), '<a href="https://wordpress.org/plugins/breadcrumb-navxt/" target="_blank">', '</a>'),
		'section'     => 'breadcrumb_section',
		'type'        => 'select',
		'choices'     => array(
			'disabled'   => esc_html__('Disabled', 'blogging-icon'),
			'simple'     => esc_html__('Simple', 'blogging-icon'),
			'advanced'   => esc_html__('Advanced', 'blogging-icon'),
		),
		'priority' => 100,
	)
);

// Preloader Section.
$wp_customize->add_section('enable_preloader_option',
	array(
		'title'      => esc_html__('Preloader Options', 'blogging-icon'),
		'priority'   => 120,
		'capability' => 'edit_theme_options',
		'panel'      => 'theme_option_panel',
	)
);

// Setting enable_preloader.
$wp_customize->add_setting('enable_preloader',
	array(
		'default'           => $default['enable_preloader'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'blogging_icon_sanitize_checkbox',
	)
);
$wp_customize->add_control('enable_preloader',
	array(
		'label'    => esc_html__('Enable Preloader', 'blogging-icon'),
		'section'  => 'enable_preloader_option',
		'type'     => 'checkbox',
		'priority' => 150,
	)
);
